<h1 align="center">GRAMS</h1>

<div align="center">

![PyPI](https://img.shields.io/pypi/v/sm-grams)
![Python](https://img.shields.io/badge/python-v3.8+-blue.svg)
[![GitHub Issues](https://img.shields.io/github/issues/usc-isi-i2/GRAMS.svg)](https://github.com/usc-isi-i2/GRAMS/issues)
![Contributions welcome](https://img.shields.io/badge/contributions-welcome-orange.svg)
[![License](https://img.shields.io/badge/license-MIT-blue.svg)](https://opensource.org/licenses/MIT)

</div>

## Table of Contents
- [Introduction](#introduction)
- [Installation](#installation)
<!-- - [Example](#example)
- [Contributing](#contributing)
<!-- - [Support](#support) -->

## Introduction

GRAMS is a library to build semantic descriptions of tables to map them to Wikidata.

## Installation

Please look in the [wiki](https://github.com/usc-isi-i2/grams/wiki/Installation) for how to install GRAMS
